@@ -5,6 +5,7 @@ Pytest fixtures for pywbem end2end tests.
 from __future__ import absolute_import
 
 import os
+import io
 import warnings
 from contextlib import contextmanager
 import json
@@ -39,7 +40,7 @@ PROFILES_YAML_FILE = os.path.join('tests', 'profiles', 'profiles.yml')
 # Profile definition list.
 # The list items are profile definition items, as described in the profile
 # definition file.
-with open(PROFILES_YAML_FILE, 'r') as _fp:
+with io.open(PROFILES_YAML_FILE, 'r', encoding='utf-8') as _fp:
     PROFILE_DEFINITION_LIST = yaml.safe_load(_fp)
 del _fp  # pylint: disable=undefined-loop-variable
 
@@ -255,10 +256,13 @@ def wbem_connection(request, es_server):
 
     nickname = es_server.nickname
 
+    # Keep the usage of the items in the es_server object in sync with the
+    # schemas defining them in the es_schema.yml file.
+
     url = es_server.user_defined['url']
     default_namespace = es_server.user_defined.get('default_namespace', None)
-    user = es_server.secrets['user']
-    password = es_server.secrets['password']
+    user = es_server.secrets.get('user', None)
+    password = es_server.secrets.get('password', None)
     no_verification = es_server.secrets.get('no_verification', None)
     ca_certs = es_server.secrets.get('ca_certs', None)
     cert_file = es_server.secrets.get('cert_file', None)
